@@ -24,7 +24,7 @@ def _list_of_dicts_to_dict_of_lists(dicts: List[Dict], mode: str, verbose=False)
     return dict(task_values)
 
 
-def _load_dir_as_dict(out_dir, wrapper_fn_dict, subset):
+def _load_dir_as_dict(out_dir, wrapper_fn_dict, subset, mode):
     dct = {}
     children = sorted(list(out_dir.iterdir()))
     for path in children:
@@ -34,7 +34,7 @@ def _load_dir_as_dict(out_dir, wrapper_fn_dict, subset):
         if subset and key not in subset:
             continue
         wrapper_fn = wrapper_fn_dict.get(key)
-        dct[key] = generic.open_existing(path, wrapper_fn=wrapper_fn)
+        dct[key] = generic.open_existing(path, wrapper_fn=wrapper_fn, mode=mode)
     return dct
 
 
@@ -74,7 +74,7 @@ def _create_mmap_for_key(out_dir, key, values, verbose):
     if selected_type in [bool, int, float]:
         _create_numpy_mmap_for_key(out_dir, key, values, verbose)
         return
-    if np.issubdtype(selected_type, np.generic):
+    if np.issubdtype(selected_type, np.number) or selected_type == np.datetime64:
         _create_numpy_mmap_for_key(out_dir, key, values, verbose)
         return
     if selected_type in [list, tuple]:
