@@ -15,11 +15,13 @@ class DataFrameMmap:
             wrapper_fn_dict: Dict[str, Callable] = None,
             subset: Optional[List[str]] = None,
             target_keys: Optional[List[str]] = None,
+            mode: str = 'r+b',
     ):
         self._out_dir = Path(out_dir)
         self._wrapper_fn_dict = {} if wrapper_fn_dict is None else wrapper_fn_dict
         self._subset = subset
-        self._data = _load_dir_as_dict(self._out_dir, self._wrapper_fn_dict, self._subset)
+        self._mode = mode
+        self._data = self._load_dir_as_dict()
         self._target_keys = set(target_keys) if target_keys else None
 
     def get_columns(self) -> List[str]:
@@ -64,7 +66,10 @@ class DataFrameMmap:
                 np_ninja.extend(mmap, np.asarray(new_value))
             else:
                 mmap.extend(new_value)
-        self._data = _load_dir_as_dict(self._out_dir, self._wrapper_fn_dict, self._subset)
+        self._data = self._load_dir_as_dict()
+
+    def _load_dir_as_dict(self):
+        return _load_dir_as_dict(self._out_dir, self._wrapper_fn_dict, self._subset, self._mode)
 
     @classmethod
     def from_list_of_dicts(
